@@ -1,19 +1,12 @@
 (in-package :closer-mop)
 
-;; Some utility functions.
+;; This is a useful utility function.
 
 (defun required-args (lambda-list &optional (collector #'identity))
   (loop for arg in lambda-list
         until (member arg lambda-list-keywords)
         collect (funcall collector arg)))
 
-(defun ensure-finalized (class &optional (errorp t))
-  (if (typep class 'class)
-    (unless (class-finalized-p class)
-      (finalize-inheritance class))
-    (when errorp (error "~S is not a class." class)))
-  class)
-
 ;; We need a new standard-generic-function for various things.
 
 (cl:defclass standard-generic-function (cl:standard-generic-function)
@@ -301,9 +294,9 @@
   `(eql ,object))
 
 (cl:defclass eql-specializer* (metaobject)
-  ((obj :reader eql-specializer-object
-        :initarg eso
-        :initform (error "Use intern-eql-specializer to create eql-specializers."))
+  ((object :reader eql-specializer-object
+           :initarg eso
+           :initform (error "Use intern-eql-specializer to create eql-specializers."))
    (direct-methods :reader specializer-direct-methods
                    :accessor es-direct-methods
                    :initform ())))
