@@ -16,7 +16,7 @@
    #:eql-specializer
    #:forward-referenced-class
    #:funcallable-standard-class
-   #-(or mcl openmcl) #:funcallable-standard-object
+   #-mcl #:funcallable-standard-object
    #:metaobject
    #:slot-definition
    #:specializer
@@ -40,7 +40,7 @@
    #:class-precedence-list
    #:class-prototype
    #:class-slots
-   #-(or mcl openmcl) #:compute-applicable-methods-using-classes
+   #-mcl #:compute-applicable-methods-using-classes
    #:compute-class-precedence-list
    #:compute-default-initargs
    #:compute-discriminating-function
@@ -66,7 +66,7 @@
    #:generic-function-methods
    #:generic-function-name
    #:intern-eql-specializer
-   #-(or mcl openmcl) #:make-method-lambda
+   #-mcl #:make-method-lambda
    #:map-dependents
    #:method-function
    #:method-generic-function
@@ -102,7 +102,7 @@
    #:eql-specializer
    #:forward-referenced-class
    #:funcallable-standard-class
-   #-(or mcl openmcl) #:funcallable-standard-object
+   #-mcl #:funcallable-standard-object
    #:metaobject
    #:slot-definition
    #:specializer
@@ -113,7 +113,6 @@
    #:standard-slot-definition
    #:standard-writer-method
 
-   #:ensure-finalized
    #:ensure-method
    #:fix-slot-initargs
    #:required-args
@@ -131,7 +130,7 @@
    #:class-precedence-list
    #:class-prototype
    #:class-slots
-   #-(or mcl openmcl) #:compute-applicable-methods-using-classes
+   #-mcl #:compute-applicable-methods-using-classes
    #:compute-class-precedence-list
    #:compute-default-initargs
    #:compute-discriminating-function
@@ -157,7 +156,7 @@
    #:generic-function-methods
    #:generic-function-name
    #:intern-eql-specializer
-   #-(or mcl openmcl) #:make-method-lambda
+   #-mcl #:make-method-lambda
    #:map-dependents
    #:method-function
    #:method-generic-function
@@ -167,7 +166,7 @@
    #:remove-dependent
    #:remove-direct-method
    #:remove-direct-subclass
-   #-(or mcl openmcl) #:set-funcallable-instance-function
+   #-mcl #:set-funcallable-instance-function
    #:slot-boundp-using-class
    #:slot-definition-allocation
    #:slot-definition-initargs
