@@ -1,19 +1,12 @@
 (in-package :closer-mop)
 
-;; Some utility functions.
+;; This is a useful utility function.
 
 (defun required-args (lambda-list &optional (collector #'identity))
   (loop for arg in lambda-list
         until (member arg lambda-list-keywords)
         collect (funcall collector arg)))
 
-(defun ensure-finalized (class &optional (errorp t))
-  (if (typep class 'class)
-    (unless (class-finalized-p class)
-      (finalize-inheritance class))
-    (when errorp (error "~S is not a class." class)))
-  class)
-
 #-openmcl
 (progn
   ;; We need a new standard-class for various things.
