@@ -1,19 +1,12 @@
 (in-package :closer-mop)
 
-;; Some utility functions.
+;; This is a useful utility function.
 
 (defun required-args (lambda-list &optional (collector #'identity))
   (loop for arg in lambda-list
         until (member arg lambda-list-keywords)
         collect (funcall collector arg)))
 
-(defun ensure-finalized (class &optional (errorp t))
-  (if (typep class 'class)
-    (unless (class-finalized-p class)
-      (finalize-inheritance class))
-    (when errorp (error "~S is not a class." class)))
-  class)
-
 ;; The following is commented out. SBCL now supports compatible standard-class and
 ;; funcallable-standard-class metaclasses, but this requires that we don't mess with
 ;; the class hierarchy anymore. So we will try the trick we have already used
@@ -69,11 +62,10 @@
        (:metaclass standard-class))))
 |#
 
-;; In CMUCL, reader-method-class and writer-method-class are
+;; In CMUCL and SBCL, reader-method-class and writer-method-class are
 ;; not used during class initialization. The following definitions
 ;; correct this.
 
-#-sbcl
 (defun modify-accessors (class)
   (loop with reader-specializers = (list class)
         with writer-specializers = (list (find-class 't) class)
@@ -105,7 +97,6 @@
 ;; unless a name is explicitly provided. AMOP requires classes to be
 ;; potentially anonymous.
 
-#-sbcl
 (cl:defmethod initialize-instance :around
   ((class standard-class) &rest initargs
    &key (name (gensym)))
@@ -113,7 +104,6 @@
   (prog1 (apply #'call-next-method class :name name initargs)
     (modify-accessors class)))
 
-#-sbcl
 (cl:defmethod initialize-instance :around
   ((class funcallable-standard-class) &rest initargs
    &key (name (gensym)))
@@ -121,12 +111,10 @@
   (prog1 (apply #'call-next-method class :name name initargs)
     (modify-accessors class)))
 
-#-sbcl
 (cl:defmethod reinitialize-instance :after
   ((class standard-class) &key)
   (modify-accessors class))
 
-#-sbcl
 (cl:defmethod reinitialize-instance :after
   ((class funcallable-standard-class) &key)
   (modify-accessors class))
@@ -137,9 +125,9 @@
 ;; The following method additionally ensures that
 ;; compute-discriminating-function is triggered.
 
-; Note that for CMUCL, these methods violate the AMOP specification
+; Note that for CMUCL and SBCL, these methods violate the AMOP specification
 ; by specializing on the original standard-generic-function metaclass. However,
-; this is necassary because in CMUCL, only one subclass of
+; this is necassary because in CMUCL and SBCL, only one subclass of
 ; standard-generic-function can be created, and taking away that option from user
 ; code doesn't make a lot of sense in our context.
 
@@ -165,7 +153,7 @@
   (map-dependents
    gf (lambda (dep) (update-dependent gf dep 'remove-method method))))
 
-#+sbcl
+#|
 (defun ensure-method (gf lambda-expression 
                          &key (method-class (generic-function-method-class gf))
                          (qualifiers ())
@@ -181,21 +169,20 @@
                          :qualifiers qualifiers
                          :lambda-list lambda-list
                          :specializers specializers
-                         :function (compile nil method-lambda)
+                         :function (compile nil (print method-lambda))
                          method-args)))
       (add-method gf method)
       method)))
+|#
 
-#|
+#+sbcl
 (defgeneric transform-specializer (specializer)
   (:method (specializer) specializer)
   (:method ((specializer class))
    (class-name specializer))
   (:method ((specializer eql-specializer))
    `(eql ,(eql-specializer-object specializer))))
-|#
 
-#-sbcl
 (defun ensure-method (gf lambda-expression 
                          &key (qualifiers ())
                          (lambda-list (cadr lambda-expression))
@@ -204,7 +191,9 @@
                            (defmethod ,(generic-function-name gf) ,@qualifiers
                              ,(loop for specializer in specializers
                                     for (arg . rest) on lambda-list
-                                    collect `(,arg ,specializer) into args
+                                    collect `(,arg ,
+                                                   #-sbcl specializer
+                                                   #+sbcl (transform-specializer specializer)) into args
                                     finally (return (nconc args rest)))
                              ,@(cddr lambda-expression))))))
 
@@ -247,40 +236,38 @@
          (keys-to-fix (loop for (key value) on counts by #'cddr
                             if (> value 1) collect key)))
     (if keys-to-fix
-      (let ((multiple-standard-keys
-             (intersection keys-to-fix *standard-slot-keys*)))
-        (if multiple-standard-keys
-          (error "Too many occurences of ~S in slot initargs ~S."
-                 multiple-standard-keys initargs)
-          (loop with fixed-keys
-                for (key value) on initargs by #'cddr
-                if (member key keys-to-fix)
-                do (nconcf (getf fixed-keys key) (list value))
-                else nconc (list key value) into fixed-initargs
-                finally (return (nconc fixed-initargs fixed-keys)))))
+        (let ((multiple-standard-keys
+               (intersection keys-to-fix *standard-slot-keys*)))
+          (if multiple-standard-keys
+              (error "Too many occurences of ~S in slot initargs ~S."
+                     multiple-standard-keys initargs)
+            (loop with fixed-keys
+                  for (key value) on initargs by #'cddr
+                  if (member key keys-to-fix)
+                  do (nconcf (getf fixed-keys key) (list value))
+                  else nconc (list key value) into fixed-initargs
+                  finally (return (nconc fixed-initargs fixed-keys)))))
       initargs)))
 
-;; In CMUCL, TYPEP and SUBTYPEP don't work as expected
-;; in conjunction with class metaobjects.
+;; TYPEP and SUBTYPEP don't work as expected in conjunction with
+;; class metaobjects
 
-#-sbcl
-(progn
-  (defgeneric typep (object type)
-    (:method (object type)
-     (cl:typep object type))
-    (:method (object (type class))
-     (cl:typep object (class-name type))))
+(defgeneric typep (object type)
+  (:method (object type)
+   (cl:typep object type))
+  (:method (object (type class))
+   (cl:typep object (class-name type))))
 
-  (defgeneric subtypep (type1 type2)
-    (:method (type1 type2)
-     (cl:subtypep type1 type2))
-    (:method ((type1 class) type2)
-     (cl:subtypep (class-name type1) type2))
-    (:method (type1 (type2 class))
-     (cl:subtypep type1 (class-name type2)))
-    (:method ((type1 class) (type2 class))
-     (cl:subtypep (class-name type1)
-                  (class-name type2)))))
+(defgeneric subtypep (type1 type2)
+  (:method (type1 type2)
+   (cl:subtypep type1 type2))
+  (:method ((type1 class) type2)
+   (cl:subtypep (class-name type1) type2))
+  (:method (type1 (type2 class))
+   (cl:subtypep type1 (class-name type2)))
+  (:method ((type1 class) (type2 class))
+   (cl:subtypep (class-name type1)
+                (class-name type2))))
 
 (eval-when (:compile-toplevel :load-toplevel :execute)
   (pushnew :closer-mop *features*))
